/* Color scheme */

:root {
    --md-primary-fg-color: hsla(175, 100%, 26%, 1);
    --md-primary-fg-color--light: hsla(175, 100%, 36%, 1);
    --md-primary-fg-color--dark: hsla(175, 100%, 16%, 1);
    --md-primary-bg-color: hsla(0, 0%, 100%, 1);
    --md-primary-bg-color--light: hsla(0, 0%, 100%, 0.7);
    --md-accent-fg-color: hsla(175, 100%, 40%, 1);
    --md-accent-fg-color--transparent: hsla(220, 76%, 61%, 0.1);
    --md-accent-bg-color: hsla(0, 0%, 100%, 1);
    --md-accent-bg-color--light: hsla(0, 0%, 100%, 0.7);
    --md-code-font: "JetBrains Mono";
}

/* Typography */

@font-face {
    font-display: swap;
    font-family: "JetBrains Mono";
    src: url("../assets/JetBrainsMono-Variable.woff2") format("woff2");
    font-weight: 100 800;
    font-style: normal;
}

@font-face {
    font-display: swap;
    font-family: "JetBrains Mono";
    src: url("../assets/JetBrainsMono-Italic-Variable.woff2") format("woff2");
    font-weight: 100 800;
    font-style: italic;
}

body {
    -webkit-font-smoothing: auto;
}

.md-nav {
    font-size: 0.85rem;
    line-height: 1.2;
}

.md-typeset h1,
.md-typeset h2,
.md-typeset h3 {
    color: var(--md-default-fg-color--dark);
    font-weight: 600;
}

h2 h3,
code {
    font-weight: 400;
}

.md-typeset {
    font-size: 0.85rem;
}

.md-typeset code {
    font-size: 0.85em;
}

.md-typeset table:not([class]) {
    font-size: 0.8rem;
}

.md-typeset .admonition,
.md-typeset details {
    font-size: 0.85rem;
}